% classicconflevel.m -- a Matlab function
% modified from Husson's CONFLEVEL Matlab function
%
% Function to estimate the confidence levels for the AR1
% red noise spectrum based on the chi2 distribution
% with degrees of freedom from multitaper analysis.
% Confidence levels are 85%, 90%, 95% and 99%.
%
% Calls:
% chi2invPMTK.m -- from pmtk3.googlecode.com
%
% Inputs:
% Ax = the area of the mtm data spectrum
% npr =  number of frequencies in the mtm data spectrum.
% dt = sample rate of the data
% nw = number of tapers used in the MTM analysis
%
% Outputs:
% tabtchi: four column array containing confidence levels
% for the AR1 red noise spectrum based on data rho and
% dof's from mtm analysis.
% column 1= 85% , column 2= 90%,column 3=95% ,column 4=99%
%
% Dorothe Husson, december 2012
% NOTE revision Line 43, Linda Hinnov, April, 2014
% More revisions: remove simulations, Linda Hinnov, June, 2017

function [theored,tabtchi]=classicconflevel(nw,Ax,npr,dt,rho,fr)

% Calculate AR1 red noise spectrum
fnyq=1/(2*dt);
theored=[];
i=1;
for i=1:npr
   theored(i)=(1-rho^2)/(1-(2*rho*cos(pi*fr(i)/fnyq))+rho^2);
end;
% normalisation of the spectrum
% theored(1)=0;
Art=sum(theored)/npr;
theored=theored*(Ax/Art);
% The degrees of freedom for MTM is equal to 2*number of tapers;
% since DropLastTaper=true, then number of tapers=2*nw-1
nw2=2*(2*nw-1);
% Estimate Chi-square confidence levels for AR1 red noise spectrum
tabtchi=[];
facchi85=chi2invPMTK(0.85,nw2)/nw2;
facchi90=chi2invPMTK(0.90,nw2)/nw2;
facchi95=chi2invPMTK(0.95,nw2)/nw2;
facchi99=chi2invPMTK(0.99,nw2)/nw2;
tabtchi(:,1)=theored*facchi85;
tabtchi(:,2)=theored*facchi90;
tabtchi(:,3)=theored*facchi95;
tabtchi(:,4)=theored*facchi99;
end
