% classicredpad.m -- a Matlab function
% modified from Husson's REDCONF Matlab function
%
% Function to estimate the red noise in a signal, and calculating the
% confidence levels using based on the chi2 distribution of the theoretical 
% estimate of the red noise spectrum.
% 
% The spectral analysis method used for analyzing the input time series 
% is the prolate multitaper method using Matlab function pmtm.m
%
% ** Zero-padding is explicit!
%
% The sample step (dt) of the input time series must be constant.
% Pre-processing of the data such as detrending, if applied, must
% also be performed prior to the analysis.
%
% Calls:
% rhoAR1.m 
% classicconflevel.m
% chi2invPMTK.m 
% pmtm.m - in Matlab's Signal Processing Toolbox
% 
%
% Inputs: 
% datax= one column array with values of the input time series
% dt= sample step of the input time series
% nw= number of tapers to be used by the MTM method.
% npad = number of input data lengths to zero-pad (e.g., 10)
%
% Outputs:
% rho= lag-1 autocorrelation coefficient.
% pd= 1 column array containing the power values of the data spectrum
% fd= 1 column array containing the frequency values of the data spectrum
% theored = AR1 red noise spectrum
% tabtchi = 4 columns with 85%, 90%, 95% and 99% confidence levels
%
% EXAMPLE:
% dt=1;
% t=0:dt:2047;
% r=randn(2048,1);
% s=sin(2*pi*t/20)';
% y=5*r+s;
% nw=2;
% npad=10;
% [pd,fd,rho,theored,tabtchi]=classicredpad(detrend(y),dt,nw,npad);
% figure;plot(fd,pd);hold all;plot(fd,theored);hold all;plot(fd,tabtchi);
%
% Dorothe Husson, November 2012
% Linda Hinnov, June, 2017 - removed simulation, added zero padding
%
function [pd,fd,rho,theored,tabtchi]=classicredpad(datax,dt,nw,npad)
% calculation of the lag-1 autocorrelation coefficient
[rho]=rhoAR1(datax);
% spectral analysis of the data using MTM method (Matlab pmtm function)
% nw is the time-bandwidth product for the dssp's used as data tapers. 
% Typical choices are 2, 5/2, 3, 7/2, 4, etc.
datan=[];
nd=length(datax);
% Subtract mean value of input time series
dataxm=sum(datax)/nd;
datan=datax-dataxm;
% Spectral analysis of the data using prolate multitaper method
mpad=npad*length(datax);
[pd,wd]=pmtm(datan,nw,mpad);
fd=wd/(2*pi*dt);
npd=length(pd);
% Calculate area of the data MTM power spectrum 
Ax=(sum(pd))/npd;
% calculation of the confidence levels
[theored,tabtchi]=classicconflevel(nw,Ax,npd,dt,rho,fd);
theored=theored';
end
